Changelog
=========

0.1.1 (2014-09-25)
------------------

- Always return the super call instead of None when no sub-indices have been created yet.
- Add tests to cover the sort method with and without values.


0.1 (2014-09-23)
----------------

- Initial release.
